Define backends using common libraries.
Cursive doesn’t print anything by itself: it delegates this job to a backend library, which handles all actual input and output.
This module defines the Backend trait, as well as a few implementations
using some common libraries. Each of those included backends needs a
corresponding feature to be enabled.
Modules
- crossterm
crossterm-backend - Backend using the pure-rust crossplatform crossterm library.
- curses
ncurses-backendorpancurses-backend - Common module for the ncurses and pancurses backends.
- puppet
- Puppet backend
- termion
termion-backend - Backend using the pure-rust termion library.
Functions
- try_
default - Tries to initialize the default backend.