pub fn dummy() -> CursiveRunnableExpand description
Creates a new Cursive root using a dummy backend.
Nothing will be output. This is mostly here for tests.
pub fn dummy() -> CursiveRunnableCreates a new Cursive root using a dummy backend.
Nothing will be output. This is mostly here for tests.