Style

Struct Style 

pub struct Style {
    pub effects: Effects,
    pub color: ColorStyle,
}
Combine a color and effects.

Represents any transformation that can be applied to text.

This is a “abstract” style, which can depend on the current theme, or on the previously active style.

Fields

effects: Effects

Effects to apply.

color: ColorStyle

Color style to apply.

Implementations

Source

impl Style

pub const fn none() -> Style

Returns a new Style that doesn’t apply anything.

Same as Style::inherit_parent().

pub fn merge(styles: &[Style]) -> Style

Returns a new Style by merging all given styles.

Will use the last non-None color, and will combine all effects.

pub fn combine<S>(self, other: S) -> Style
where S: Into<Style>,

Returns a combination of self and other.

pub const fn from_color_style(color: ColorStyle) -> Style

Create a new Style from a single ColorStyle and no effect.

pub const fn inherit_parent() -> Style

Uses ColorType::InheritParent for both front and background.

pub const fn terminal_default() -> Style

Style set by terminal before entering a Cursive program.

pub const fn background() -> Style

Application background, where no view is present.

pub const fn shadow() -> Style

Color used by view shadows. Only background matters.

pub const fn view() -> Style

Style used for views.

pub const fn primary() -> Style

Main text with default background.

pub const fn secondary() -> Style

Secondary text color, with default background.

pub const fn tertiary() -> Style

Tertiary text color, with default background.

pub const fn title_primary() -> Style

Title text color with default background.

pub const fn title_secondary() -> Style

Alternative color for a title.

pub const fn highlight() -> Style

Returns a highlight style.

pub const fn highlight_inactive() -> Style

Returns an inactive highlight style.

pub fn resolve( &self, palette: &Palette, previous: ConcreteStyle, ) -> ConcreteStyle

Resolve a style to a concrete style.