Struct cursive::vec::Vec2
[−]
[src]
pub struct Vec2 {
pub x: usize,
pub y: usize,
}Simple 2D size, in characters.
Fields
x: usize
X coordinate (column), from left to right.
y: usize
Y coordinate (row), from top to bottom.
Methods
impl Vec2[src]
fn new(x: usize, y: usize) -> Self
Creates a new Vec2 from coordinates.
fn max(a: Self, b: Self) -> Self
Returns a new Vec2 that is a maximum per coordinate.
fn min(a: Self, b: Self) -> Self
Returns a new Vec2 that is no larger than any input in both dimensions.
fn keep_x(&self) -> Self
Returns a vector with the X component of self, and y=0.
fn keep_y(&self) -> Self
Returns a vector with the Y component of self, and x=0.
fn zero() -> Self
Alias for Vec::new(0,0).
fn stack_vertical(&self, other: &Vec2) -> Vec2
Returns (max(self.x,other.x), self.y+other.y)
fn stack_horizontal(&self, other: &Vec2) -> Vec2
Returns (self.x+other.x, max(self.y,other.y))