Struct cursive::views::ShadowView
[−]
[src]
pub struct ShadowView<T: View> { /* fields omitted */ }
Wrapper view that adds a shadow.
It reserves a 1 pixel border on each side.
Methods
impl<T: View> ShadowView<T>[src]
fn new(view: T) -> Self
Wraps the given view.
fn left_padding(self, value: bool) -> Self
If set, adds an empty column to the left of the view.
Default to true.
fn top_padding(self, value: bool) -> Self
If set, adds an empty row at the top of the view.
Default to true.