pub struct TextView { /* private fields */ }Expand description
A simple view showing a fixed text.
Examples
let mut siv = Cursive::new();
siv.add_layer(TextView::new("Hello world!"));Implementations
Sourceimpl TextView
impl TextView
Sourcepub fn cursup<S>(content: S) -> TextView
pub fn cursup<S>(content: S) -> TextView
Convenient function to create a TextView by parsing the given content as cursup.
Shortcut for TextView::new(cursup::parse(content)).
Examples
let view = TextView::cursup("/red+bold{warning}");Sourcepub fn new_with_content(content: TextContent) -> TextView
pub fn new_with_content(content: TextContent) -> TextView
Creates a new TextView using the given TextContent.
If you kept a clone of the given content, you’ll be able to update it remotely.
Examples
let mut content = TextContent::new("content");
let view = TextView::new_with_content(content.clone());
// Later, possibly in a different thread
content.set_content("new content");
assert!(view.get_content().source().contains("new"));Sourcepub fn set_effect(&mut self, effect: Effect)
👎Deprecated since 0.16.0: Use set_style() instead.
pub fn set_effect(&mut self, effect: Effect)
Use set_style() instead.
Sets the effect for the entire content.
Sourcepub fn effect(self, effect: Effect) -> TextView
👎Deprecated since 0.16.0: Use style() instead.
pub fn effect(self, effect: Effect) -> TextView
Use style() instead.
Sets the effect for the entire content.
Chainable variant.
Sourcepub fn style<S>(self, style: S) -> TextView
pub fn style<S>(self, style: S) -> TextView
Sets the style for the entire content.
Chainable variant.
Sourcepub fn no_wrap(self) -> TextView
pub fn no_wrap(self) -> TextView
Disables content wrap for this view.
This may be useful if you want horizontal scrolling.
Sourcepub fn set_content_wrap(&mut self, wrap: bool)
pub fn set_content_wrap(&mut self, wrap: bool)
Controls content wrap for this view.
If true (the default), text will wrap long lines when needed.
Sourcepub fn content<S>(self, content: S) -> TextView
pub fn content<S>(self, content: S) -> TextView
Replace the text in this view.
Chainable variant.
Sourcepub fn set_content<S>(&mut self, content: S)
pub fn set_content<S>(&mut self, content: S)
Replace the text in this view.
Sourcepub fn get_content(&self) -> TextContentRef
pub fn get_content(&self) -> TextContentRef
Returns the current text in this view.
Returns a shared reference to the content, allowing content mutation.