[−][src]Enum cursive::event::Event
Represents an event as seen by the application.
Variants
Event fired when the window is resized.
Event fired regularly when a auto-refresh is set.
Char(char)A character was entered (includes numbers, punctuation, ...).
CtrlChar(char)A character was entered with the Ctrl key pressed.
AltChar(char)A character was entered with the Alt key pressed.
Key(Key)A non-character key was pressed.
Shift(Key)A non-character key was pressed with the Shift key pressed.
Alt(Key)A non-character key was pressed with the Alt key pressed.
AltShift(Key)A non-character key was pressed with the Shift and Alt keys pressed.
Ctrl(Key)A non-character key was pressed with the Ctrl key pressed.
CtrlShift(Key)A non-character key was pressed with the Ctrl and Shift keys pressed.
CtrlAlt(Key)A non-character key was pressed with the Ctrl and Alt keys pressed.
A mouse event was sent.
Fields of Mouse
offset: XY<usize>Position of the top-left corner of the view receiving this event.
position: XY<usize>Position of the mouse when this event was fired.
event: MouseEventThe mouse event itself.
An unknown event was received.
Implementations
impl Event[src]
pub fn mouse_position(&self) -> Option<XY<usize>>[src]
Returns the position of the mouse, if self is a mouse event.
pub fn mouse_position_mut(&mut self) -> Option<&mut XY<usize>>[src]
Returns a mutable reference to the position of the mouse/
Returns None if self is not a mouse event.
pub fn relativize<V>(&mut self, top_left: V) where
V: Into<XY<usize>>, [src]
V: Into<XY<usize>>,
Update self with the given offset.
If self is a mouse event, adds top_left to its offset.
Otherwise, do nothing.
pub fn relativized<V>(&self, top_left: V) -> Event where
V: Into<XY<usize>>, [src]
V: Into<XY<usize>>,
Returns a cloned, relativized event.
If self is a mouse event, adds top_left to its offset.
Otherwise, returns a simple clone.