pub struct SizeCache<T = ()> {
pub value: usize,
pub constrained: bool,
pub extra: T,
}Expand description
Cache around a one-dimensional layout result.
This is not a View, but something to help you if you create your own Views.
Fields
value: usizeCached value
constrained: booltrue if the last size was constrained.
If unconstrained, any request larger than this value would return the same size.
extra: TExtra field.
Implementations
Sourceimpl SizeCache
impl SizeCache
Sourcepub fn build(size: XY<usize>, req: XY<usize>) -> XY<SizeCache>
pub fn build(size: XY<usize>, req: XY<usize>) -> XY<SizeCache>
Creates a new bi-dimensional cache.
It will stay valid for the same request, and compatible ones.
A compatible request is one where, for each axis, either:
- the request is equal to the cached size, or
- the request is larger than the cached size and the cache is unconstrained
Notes:
sizemust fit insidereq.- for each dimension,
constrained = (size == req)
Sourceimpl<T> SizeCache<T>
impl<T> SizeCache<T>
Sourcepub fn new_extra(value: usize, constrained: bool, extra: T) -> SizeCache<T>
pub fn new_extra(value: usize, constrained: bool, extra: T) -> SizeCache<T>
Creates a new sized cache
Sourcepub fn build_extra(
size: XY<usize>,
req: XY<usize>,
extra: XY<T>,
) -> XY<SizeCache<T>>
pub fn build_extra( size: XY<usize>, req: XY<usize>, extra: XY<T>, ) -> XY<SizeCache<T>>
Creates a new bi-dimensional cache.
Similar to build(), but includes the extra field.