Module views

Module views 

Various views to use when creating the layout.

Modules

stack_view
Helpers for StackView.

Structs

BoxedView
A boxed View.
Button
Simple text label with a callback when <Enter> is pressed.
Canvas
A blank view that forwards calls to closures.
Checkbox
Checkable box.
CircularFocus
Adds circular focus to a wrapped view.
DebugView
View used for debugging, showing logs.
Dialog
Popup-like view with a main content, and optional buttons under it.
DummyView
Dummy view.
EditView
Input box where the user can enter and edit text.
EnableableView
Wrapper around another view that can be enabled/disabled at will.
FixedLayout
Arranges its children in a fixed layout.
FocusTracker
Detects focus events for a view.
GradientView
Wraps a view and applies a gradient to it.
HideableView
Wrapper around another view that can be hidden at will.
LastSizeView
Wrapper around a view that remembers its size.
Layer
Wrapper view that fills the background.
LinearLayout
Arranges its children linearly according to its orientation.
ListView
Displays a list of elements.
MenuPopup
Popup that shows a list of items.
Menubar
Shows a single-line list of items, with pop-up menus when one is selected.
NamedView
Wrapper around a view to make it identifiable.
OnEventView
A wrapper view that can react to events.
OnLayoutView
View wrapper overriding the View::layout method.
PaddedView
Adds padding to another view.
Panel
Draws a border around a wrapped view.
ProgressBar
Animated bar showing a progress value.
RadioButton
Variant of Checkbox arranged in group.
RadioGroup
Group to coordinate multiple radio buttons.
ResizedView
Wrapper around another view, with a controlled size.
ScreensView
A view that can switch between different screens.
ScrollView
Wraps a view in a scrollable area.
SelectView
View to select an item among a list.
ShadowView
Wrapper view that adds a shadow.
SliderView
A horizontal or vertical slider.
StackView
Simple stack of views. Only the top-most view is active and can receive input.
TextArea
Multi-lines text editor.
TextContent
Provides access to the content of a TextView.
TextContentRef
A reference to the text content.
TextView
A simple view showing a fixed text.
ThemedView
Applies a theme to the wrapped view.
TrackedView
Wrapper around a view that remembers its position.
ViewRef
Mutable reference to a view.

Enums

DialogFocus
Identifies currently focused element in Dialog.
LayerPosition
Identifies a layer in a StackView.
ListChild
Represents a child from a ListView.