Various views to use when creating the layout.
Modules
- stack_
view - Helpers for
StackView.
Structs
- Boxed
View - A boxed
View. - Button
- Simple text label with a callback when
<Enter>is pressed. - Canvas
- A blank view that forwards calls to closures.
- Checkbox
- Checkable box.
- Circular
Focus - Adds circular focus to a wrapped view.
- Debug
View - View used for debugging, showing logs.
- Dialog
- Popup-like view with a main content, and optional buttons under it.
- Dummy
View - Dummy view.
- Edit
View - Input box where the user can enter and edit text.
- Enableable
View - Wrapper around another view that can be enabled/disabled at will.
- Fixed
Layout - Arranges its children in a fixed layout.
- Focus
Tracker - Detects focus events for a view.
- Gradient
View - Wraps a view and applies a gradient to it.
- Hideable
View - Wrapper around another view that can be hidden at will.
- Last
Size View - Wrapper around a view that remembers its size.
- Layer
- Wrapper view that fills the background.
- Linear
Layout - Arranges its children linearly according to its orientation.
- List
View - Displays a list of elements.
- Menu
Popup - Popup that shows a list of items.
- Menubar
- Shows a single-line list of items, with pop-up menus when one is selected.
- Named
View - Wrapper around a view to make it identifiable.
- OnEvent
View - A wrapper view that can react to events.
- OnLayout
View - View wrapper overriding the
View::layoutmethod. - Padded
View - Adds padding to another view.
- Panel
- Draws a border around a wrapped view.
- Progress
Bar - Animated bar showing a progress value.
- Radio
Button - Variant of
Checkboxarranged in group. - Radio
Group - Group to coordinate multiple radio buttons.
- Resized
View - Wrapper around another view, with a controlled size.
- Screens
View - A view that can switch between different screens.
- Scroll
View - Wraps a view in a scrollable area.
- Select
View - View to select an item among a list.
- Shadow
View - Wrapper view that adds a shadow.
- Slider
View - A horizontal or vertical slider.
- Stack
View - Simple stack of views. Only the top-most view is active and can receive input.
- Text
Area - Multi-lines text editor.
- Text
Content - Provides access to the content of a
TextView. - Text
Content Ref - A reference to the text content.
- Text
View - A simple view showing a fixed text.
- Themed
View - Applies a theme to the wrapped view.
- Tracked
View - Wrapper around a view that remembers its position.
- ViewRef
- Mutable reference to a view.
Enums
- Dialog
Focus - Identifies currently focused element in
Dialog. - Layer
Position - Identifies a layer in a
StackView. - List
Child - Represents a child from a
ListView.