pub struct Button { /* private fields */ }Expand description
Simple text label with a callback when <Enter> is pressed.
A button shows its content in a single line and has a fixed size.
Examples
use cursive_core::views::Button;
let quit_button = Button::new("Quit", |s| s.quit());Implementations
Sourceimpl Button
impl Button
Sourcepub fn set_enabled(&mut self, enabled: bool)
pub fn set_enabled(&mut self, enabled: bool)
Enable or disable this view.
Sourcepub fn with_enabled(self, is_enabled: bool) -> Button
pub fn with_enabled(self, is_enabled: bool) -> Button
Enable or disable this view.
Chainable variant.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true if this view is enabled.
Sourcepub fn new<F, S>(label: S, cb: F) -> Button
pub fn new<F, S>(label: S, cb: F) -> Button
Creates a new button with the given content and callback.
Sourcepub fn new_cb<F>(cb: F) -> Arc<dyn Fn(&mut Cursive) + Sync + Send> ⓘ
pub fn new_cb<F>(cb: F) -> Arc<dyn Fn(&mut Cursive) + Sync + Send> ⓘ
Helper method to store a callback of the correct type for Self::new.
This is mostly useful when using this view in a template.
Sourcepub fn new_with_cb<S>(
label: S,
cb: Arc<dyn Fn(&mut Cursive) + Sync + Send>,
) -> Button
pub fn new_with_cb<S>( label: S, cb: Arc<dyn Fn(&mut Cursive) + Sync + Send>, ) -> Button
Helper method to call Self::new with a variable from a config.
This is mostly useful when writing a cursive blueprint for this view.
Sourcepub fn new_raw<F, S>(label: S, cb: F) -> Button
pub fn new_raw<F, S>(label: S, cb: F) -> Button
Creates a new button without angle brackets.
Examples
use cursive_core::views::Button;
let button = Button::new_raw("[ Quit ]", |s| s.quit());Sourcepub fn set_callback<F>(&mut self, cb: F)
pub fn set_callback<F>(&mut self, cb: F)
Sets the function to be called when the button is pressed.
Replaces the previous callback.
Sourcepub fn label(&self) -> &str
pub fn label(&self) -> &str
Returns the label for this button.
Includes brackets.
Examples
let button = Button::new("Quit", |s| s.quit());
assert_eq!(button.label(), "<Quit>");Sourcepub fn set_label<S>(&mut self, label: S)
pub fn set_label<S>(&mut self, label: S)
Sets the label to the given value.
This will include brackets.
Examples
use cursive_core::views::Button;
let mut button = Button::new("Quit", |s| s.quit());
button.set_label("Escape");Sourcepub fn set_label_raw<S>(&mut self, label: S)
pub fn set_label_raw<S>(&mut self, label: S)
Sets the label exactly to the given value.
This will not include brackets.