Button

Struct Button 

pub struct Button { /* private fields */ }
Simple text label with a callback when <Enter> is pressed.

A button shows its content in a single line and has a fixed size.

Examples

use cursive_core::views::Button;

let quit_button = Button::new("Quit", |s| s.quit());

Implementations

Source

impl Button

pub fn disable(&mut self)

Disables this view.

A disabled view cannot be selected.

pub fn disabled(self) -> Button

Disables this view.

Chainable variant.

pub fn enable(&mut self)

Re-enables this view.

pub fn set_enabled(&mut self, enabled: bool)

Enable or disable this view.

pub fn with_enabled(self, is_enabled: bool) -> Button

Enable or disable this view.

Chainable variant.

pub fn is_enabled(&self) -> bool

Returns true if this view is enabled.

pub fn new<F, S>(label: S, cb: F) -> Button
where F: 'static + Fn(&mut Cursive) + Send + Sync, S: Into<SpannedString<Style>>,

Creates a new button with the given content and callback.

pub fn new_cb<F>(cb: F) -> Arc<dyn Fn(&mut Cursive) + Send + Sync>
where F: Fn(&mut Cursive) + 'static + Send + Sync,

Helper method to store a callback of the correct type for Self::new.

This is mostly useful when using this view in a template.

pub fn new_with_cb<S>( label: S, cb: Arc<dyn Fn(&mut Cursive) + Send + Sync>, ) -> Button

Helper method to call Self::new with a variable from a config.

This is mostly useful when writing a cursive blueprint for this view.

pub fn new_raw<F, S>(label: S, cb: F) -> Button
where S: Into<SpannedString<Style>>, F: 'static + Fn(&mut Cursive) + Send + Sync,

Creates a new button without angle brackets.

Examples
use cursive_core::views::Button;

let button = Button::new_raw("[ Quit ]", |s| s.quit());
pub fn set_callback<F>(&mut self, cb: F)
where F: Fn(&mut Cursive) + 'static + Send + Sync,

Sets the function to be called when the button is pressed.

Replaces the previous callback.

pub fn label(&self) -> &str

Returns the label for this button.

Includes brackets.

Examples
let button = Button::new("Quit", |s| s.quit());
assert_eq!(button.label(), "<Quit>");
pub fn set_label<S>(&mut self, label: S)
where S: Into<String>,

Sets the label to the given value.

This will include brackets.

Examples
use cursive_core::views::Button;

let mut button = Button::new("Quit", |s| s.quit());
button.set_label("Escape");
pub fn set_label_raw<S>(&mut self, label: S)

Sets the label exactly to the given value.

This will not include brackets.